@@ -20,13 +20,13 @@ def cli():
 
 @cli.command()
 def generate_certificate():
-    CN = prompt("What is your client id?", hide_input=False)
-    ORG = prompt("What is your client id?", hide_input=False)
-    ORG_UNIT = prompt("What is your client id?", hide_input=False)
-    L = prompt("What is your client id?", hide_input=False)
-    ST = prompt("What is your client id?", hide_input=False)
-    C = prompt("What is your client id?", hide_input=False)
-    EMAIL = prompt("What is your client id?", hide_input=False)
+    CN = prompt("Domain", hide_input=False)
+    ORG = prompt("Organization", hide_input=False)
+    ORG_UNIT = prompt("Department", hide_input=False)
+    L = prompt("City", hide_input=False)
+    ST = prompt("State", hide_input=False)
+    C = prompt("Country", hide_input=False)
+    EMAIL = prompt("Email", hide_input=False)
 
     NETSUITE_KEY_FILE = prompt("Netsuite Key FIle Name['./netsuite-key']: ", default=api_settings.NETSUITE_KEY_FILE)
     CERTIFICATE_FILE = './netsuite-certificate.pem'
@@ -65,7 +65,7 @@ def generate_certificate():
 def generate_client_config():
     client_id = prompt("What is your client id?", hide_input=False)
     cert_id = prompt("What is your Netsuite certificate id?", hide_input=False)
-    cert_file = prompt("Name of Netsuite Key File?", hide_input=False)
+    cert_file = prompt("Name of Netsuite Key File['netsuite-key.pem']?", hide_input=False)
 
     # client_secret = prompt("What is your client secret?", hide_input=True)
     # redirect_url = prompt("Redirect URL", default=api_settings.REDIRECT_URL)
